﻿using Hotline.Caching.Interfaces;
using Hotline.File;
using Hotline.Repository.SqlSugar.Extensions;
using Hotline.Share.Dtos;
using Hotline.Share.Dtos.Snapshot;
using Hotline.Share.Tools;
using Hotline.Snapshot;
using Hotline.Snapshot.Interfaces;
using Mapster;
using SqlSugar;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using XF.Domain.Dependency;

namespace Hotline.Application.Snapshot;
public class IndustryApplication : IIndustryApplication, IScopeDependency
{
    private readonly IIndustryRepository _industryRepository;
    private readonly IFileRepository _fileRepository;
    private readonly ISystemSettingCacheManager _sysSetting;

    public IndustryApplication(IIndustryRepository industryRepository, IFileRepository fileRepository, ISystemSettingCacheManager sysSetting)
    {
        _industryRepository = industryRepository;
        _fileRepository = fileRepository;
        _sysSetting = sysSetting;
    }

    /// <summary>
    /// 新增行业
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    /// <exception cref="NotImplementedException"></exception>
    public async Task<string> AddIndustryAsync(AddIndustryDto dto, CancellationToken cancellationToken)
    {
        var entity = dto.Adapt<Industry>();
        var id = await _industryRepository.AddAsync(entity, cancellationToken);
        if (dto.Files.NotNullOrEmpty())
        {
            var fileEntities = dto.Files.Adapt<List<Hotline.File.File>>();
            fileEntities.ForEach(m => m.Key = id);
            await _fileRepository.AddRangeAsync(fileEntities, cancellationToken);
        }
        return id;
    }

    public ISugarQueryable<IndustryItemsOutDto> GetIndustres(IndustryListInDto dto)
    {
        var query = _industryRepository.Queryable()
            .WhereIF(dto.Name.NotNullOrEmpty(), m => m.Name.Contains(dto.Name))
            .WhereIF(dto.ApproveOrgName.NotNullOrEmpty(), m => m.ApproveOrgName.Contains(dto.ApproveOrgName))
            .Select<IndustryItemsOutDto>();
        

        return query;
    }

    public async Task<IndustryDetailOutDto> GetIndustryDetailAsync(string id)
    {
        var fileServiceUrl = _sysSetting.FileServerUrl;
        var fileDownloadApi = fileServiceUrl + _sysSetting.FileDownloadApi;
        var industry = await _industryRepository.GetAsync(id);
        var files = await _fileRepository.GetByKeyAsync(id, CancellationToken.None);
        var outDto = industry.Adapt<IndustryDetailOutDto>();
        outDto.Files = files.Adapt<IList<IndustryFileDto>>();
        if (outDto.BackgroundImgUrl.NotNullOrEmpty())
            outDto.BackgroundImgUrl = fileDownloadApi + outDto.BackgroundImgUrl;
        if (outDto.BannerImgUrl.NotNullOrEmpty())
            outDto.BannerImgUrl = fileDownloadApi + outDto.BannerImgUrl;
        if (outDto.CareCellImgUrl.NotNullOrEmpty())
            outDto.CareCellImgUrl = fileDownloadApi + outDto.CareCellImgUrl;
        if (outDto.CellImgUrl.NotNullOrEmpty())
            outDto.CellImgUrl = fileDownloadApi + outDto.CellImgUrl;
        return outDto;
    }
}
